{% extends "admin/change_form.html" %}

{% load i18n %}

{% block object-tools-items %}
    <li><a target="_blank" href="{{ original.get_test_url }}">{% trans "Test IdP" %}</a></li>
    {{ block.super }}
{% endblock object-tools-items %}
