{% load i18n %}

<html>
<head>
    <title>{% trans "SSO Error" %} - {{ idp }}</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
</head>
<body>
    <div class="container">
        <h1 class="mt-2 mb-4 pb-2 border-bottom">{% trans "SSO Error" %}</h1>
        <p>{{ reason }}</p>
        <p>{% trans "State" %}: <code>{{ state }}</code></p>
        <ul>
            {% for err in errors %}
                <li>{{ err }}</li>
            {% endfor %}
        </ul>
    </div>
</body>
</html>
